
TODO: TODO_98_35_14_72: exclude `class_name` from `search_control`

*   Add `class_name` into all `search_control`-s explicitly (where needed).
*   Remove `class_name` from `search_control`-s schema.

Based on FS_45_08_22_15 data model manipulation, `search_control` specifies what to search in collection.
And `class_name` is part of the structure, but it is not supposed to be always needed.
There should be a way to search collections with multiple `class_name`-s in it without specifying which one. 
